@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use Sisimai::MTA;
 
-sub description { '' }
-sub headerlist  { [] }
-
+sub description    { '' }
+sub headerlist     { [] }
 sub SMTPCOMMAND    { return Sisimai::MTA->SMTPCOMMAND    }
 sub EOM            { return Sisimai::MTA->EOM            }
 sub DELIVERYSTATUS { return Sisimai::MTA->DELIVERYSTATUS }
 sub LONGFIELDS     { return Sisimai::MTA->LONGFIELDS     }
+sub INDICATORS     { return Sisimai::MTA->INDICATORS     }
 sub RFC822HEADERS  { 
     my $class = shift;
     my $argvs = shift;
@@ -18,17 +18,15 @@ sub RFC822HEADERS  {
 }
 
 sub smtpagent {
-    # @Description  Return MSP name: Call smtpagent() in each child class
-    # @Param        None
-    # @Return       (String) MSP name
+    # Return MSP name: Call smtpagent() in each child class
+    # @return   [String] MSP name
     my $class = shift; 
     return shift // 'null';
 }
 
 sub index {
-    # @Description  MSP list
-    # @Param        None
-    # @Return       (Ref->Array) MSP list with order
+    # MSP list
+    # @return   [Array] MSP list with order
     my $class = shift;
     my $index = [
         'US::Google', 'US::Yahoo', 'US::Aol', 'US::Outlook',
@@ -43,10 +41,17 @@ sub index {
 }
 
 sub scan {
-    # @Description  Detect an error
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Hash) Bounce data list and message/rfc822 part
+    # @abstract      Detect an error
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
     return '';
 }
 
