@@ -15,15 +15,22 @@ my $RxMSP = {
     },
 };
 
-sub version     { '4.1.0' }
 sub description { 'Verizon Wireless: http://www.verizonwireless.com' }
 sub smtpagent   { 'US::Verizon' }
 
 sub scan {
-    # @Description  Detect an error from Verizon
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Hash) Bounce data list and message/rfc822 part
+    # Detect an error from Verizon
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
+    # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
@@ -44,6 +51,9 @@ sub scan {
     my $rfc822next = {};    # (Ref->Hash) Check flag for the end of headers in rfc822 part
     my $previousfn = '';    # (String) Previous field name
 
+    my $readcursor = 0;     # (Integer) Points the current cursor position
+    my $indicators = __PACKAGE__->INDICATORS;
+
     my $longfields = __PACKAGE__->LONGFIELDS;
     my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
@@ -83,7 +93,17 @@ sub scan {
 
         for my $e ( @stripedtxt ) {
             # Read each line between $RxMSP->{'begin'} and $RxMSP->{'rfc822'}.
-            if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
+            unless( $readcursor ) {
+                # Beginning of the bounce message or delivery status part
+                $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxMTA->{'begin'};
+            }
+
+            unless( $readcursor & $indicators->{'message-rfc822'} ) {
+                # Beginning of the original message part
+                $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxMTA->{'rfc822'};
+            }
+
+            if( $readcursor & $indicators->{'message-rfc822'} ) {
                 # After "message/rfc822"
                 if( $e =~ m/\A\s\s([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                     # Get required headers only
@@ -110,7 +130,7 @@ sub scan {
 
             } else {
                 # Before "message/rfc822"
-                next unless ( $e =~ $RxMTA->{'begin'} ) .. ( $e =~ $RxMTA->{'rfc822'} );
+                next unless $readcursor & $indicators->{'deliverystatus'};
                 next unless length $e;
 
                 $v = $dscontents->[ -1 ];
@@ -174,7 +194,17 @@ sub scan {
 
         for my $e ( @stripedtxt ) {
             # Read each line between $RxMSP->{'begin'} and $RxMSP->{'rfc822'}.
-            if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
+            unless( $readcursor ) {
+                # Beginning of the bounce message or delivery status part
+                $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxMTA->{'begin'};
+            }
+
+            unless( $readcursor & $indicators->{'message-rfc822'} ) {
+                # Beginning of the original message part
+                $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxMTA->{'rfc822'};
+            }
+
+            if( $readcursor & $indicators->{'message-rfc822'} ) {
                 # After "message/rfc822"
                 if( $e =~ m/\A\s\s([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
                     # Get required headers only
@@ -202,7 +232,7 @@ sub scan {
 
             } else {
                 # Before "message/rfc822"
-                next unless ( $e =~ $RxMTA->{'begin'} ) .. ( $e =~ $RxMTA->{'rfc822'} );
+                next unless $readcursor & $indicators->{'deliverystatus'};
                 next unless length $e;
 
                 $v = $dscontents->[ -1 ];
@@ -306,12 +336,6 @@ Wireless>. Methods in the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
-=head2 C<B<version()>>
-
-C<version()> returns the version number of this module.
-
-    print Sisimai::MSP::US::Verizon->version;
-
 =head2 C<B<description()>>
 
 C<description()> returns description string of this module.
