@@ -29,6 +29,7 @@ use warnings;
 #
 my $RxMTA = {
     'from'      => qr/\AMail Delivery System/,
+    'alias'     => qr/\A[ ]+an[ ]undisclosed[ ]address\z/,
     'rfc822'    => qr/\A------ This is a copy of the message.+headers[.] ------\z/,
     'begin'     => qr/\AThis message was created automatically by mail delivery software[.]/,
     'endof'     => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
@@ -36,6 +37,7 @@ my $RxMTA = {
          Mail[ ]delivery[ ]failed(:[ ]returning[ ]message[ ]to[ ]sender)?
         |Warning:[ ]message[ ].+[ ]delayed[ ]+
         |Delivery[ ]Status[ ]Notification
+        |Mail[ ]failure
         )
     }x,
     'message-id' => qr/\A[<]\w+[-]\w+[-]\w+[@].+\z/,
@@ -59,6 +61,7 @@ my $RxExpr = qr{(?:
     #                 "after this message arrived";
     |retry[ ]time[ ]not[ ]reached[ ]for[ ]any[ ]host[ ]after[ ]a[ ]long[ ]failure[ ]period
     |all[ ]hosts[ ]have[ ]been[ ]failing[ ]for[ ]a[ ]long[ ]time[ ]and[ ]were[ ]last[ ]tried
+    |Delay[ ]reason:[ ]
     )
 }x;
 
@@ -108,16 +111,23 @@ my $RxSess = {
     }x,
 };
 
-sub version     { '4.1.0' }
 sub description { 'Exim' }
 sub smtpagent   { 'Exim' }
 sub headerlist  { return [ 'X-Failed-Recipients' ] }
 
 sub scan {
-    # @Description  Detect an error from Exim
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Hash) Bounce data list and message/rfc822 part
+    # Detect an error from Exim
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
+    # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
@@ -131,6 +141,9 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $readcursor = 0;     # (Integer) Points the current cursor position
+    my $indicators = __PACKAGE__->INDICATORS;
+
     my $longfields = __PACKAGE__->LONGFIELDS;
     my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
@@ -143,7 +156,17 @@ sub scan {
 
     for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
-        if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
+        unless( $readcursor ) {
+            # Beginning of the bounce message or delivery status part
+            $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxMTA->{'begin'};
+        }
+
+        unless( $readcursor & $indicators->{'message-rfc822'} ) {
+            # Beginning of the original message part
+            $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxMTA->{'rfc822'};
+        }
+
+        if( $readcursor & $indicators->{'message-rfc822'} ) {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
@@ -171,7 +194,7 @@ sub scan {
 
         } else {
             # Before "message/rfc822"
-            next unless ( $e =~ $RxMTA->{'begin'} ) .. ( $e =~ $RxMTA->{'rfc822'} );
+            next unless $readcursor & $indicators->{'deliverystatus'};
             next unless length $e;
 
             # This message was created automatically by mail delivery software.
@@ -188,8 +211,12 @@ sub scan {
                 # deliver.c:6811|  "recipients. This is a permanent error. The following address(es) failed:\n");
                 $v->{'softbounce'} = 0;
 
-            } elsif( $e =~ m/\A\s+([^\s\t]+[@][^\s\t]+[.][a-zA-Z]+)\z/ ) {
+            } elsif( $e =~ m/\A\s+([^\s\t]+[@][^\s\t]+[.][a-zA-Z]+)\z/ || $e =~ $RxMTA->{'alias'} ) {
                 #   kijitora@example.jp
+                #
+                # deliver.c:4549|  printed = US"an undisclosed address";
+                #   an undisclosed address
+                #     (generated from kijitora@example.jp)
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
                     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
@@ -198,6 +225,10 @@ sub scan {
                 $v->{'recipient'} = $1;
                 $recipients++;
 
+            } elsif( $e =~ m/\A[ ]+[(]generated[ ]from[ ](.+)[)]\z/ ) {
+                #     (generated from kijitora@example.jp)
+                $v->{'alias'} = $1;
+
             } elsif( scalar @$dscontents == $recipients ) {
                 # Error message
                 next unless length $e;
@@ -217,7 +248,15 @@ sub scan {
         $e = '';
     }
 
-    unless( $recipients ) {
+    if( $recipients ) {
+        # Check "an undisclosed address", "unroutable address"
+        for my $q ( @$dscontents ) {
+            # Replace the recipient address with the value of "alias"
+            next unless $q->{'alias'};
+            $q->{'recipient'} ||= $q->{'alias'};
+        }
+
+    } else {
         # Fallback for getting recipient addresses
         if( defined $mhead->{'x-failed-recipients'} ) {
             # X-Failed-Recipients: kijitora@example.jp
@@ -308,7 +347,11 @@ sub scan {
                     }
 
                     last if $e->{'reason'};
-                    $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $RxExpr;
+                    if( $e->{'diagnosis'} =~ $RxExpr ) {
+                        # The reason "expired"
+                        $e->{'reason'} = 'expired';
+                        $e->{'softbounce'} = 1;
+                    }
                 }
                 last;
             }
@@ -342,12 +385,6 @@ the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
-=head2 C<B<version()>>
-
-C<version()> returns the version number of this module.
-
-    print Sisimai::MTA::Exim->version;
-
 =head2 C<B<description()>>
 
 C<description()> returns description string of this module.
