@@ -30,15 +30,22 @@ my $RxMTA = {
     'subject' => qr/\AUndelivered Mail Returned to Sender\z/,
 };
 
-sub version     { '4.1.0' }
 sub description { 'Postfix' }
 sub smtpagent   { 'Postfix' }
 
 sub scan {
-    # @Description  Detect an error from Postfix
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Hash) Bounce data list and message/rfc822 part
+    # Detect an error from Postfix
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
+    # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
@@ -62,6 +69,9 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $readcursor = 0;     # (Integer) Points the current cursor position
+    my $indicators = __PACKAGE__->INDICATORS;
+
     my $longfields = __PACKAGE__->LONGFIELDS;
     my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
@@ -79,9 +89,18 @@ sub scan {
 
     for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
-        if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
-            # After "message/rfc822"
+        unless( $readcursor ) {
+            # Beginning of the bounce message or delivery status part
+            $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxMTA->{'begin'};
+        }
 
+        unless( $readcursor & $indicators->{'message-rfc822'} ) {
+            # Beginning of the original message part
+            $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxMTA->{'rfc822'};
+        }
+
+        if( $readcursor & $indicators->{'message-rfc822'} ) {
+            # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
@@ -107,7 +126,7 @@ sub scan {
 
         } else {
             # Before "message/rfc822"
-            next unless ( $e =~ $RxMTA->{'begin'} ) .. ( $e =~ $RxMTA->{'rfc822'} );
+            next unless $readcursor & $indicators->{'deliverystatus'};
             next unless length $e;
 
             if( $connvalues == scalar( keys %$connheader ) ) {
@@ -313,12 +332,6 @@ in the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
-=head2 C<B<version()>>
-
-C<version()> returns the version number of this module.
-
-    print Sisimai::MTA::Postfix->version;
-
 =head2 C<B<description()>>
 
 C<description()> returns description string of this module.
