@@ -12,15 +12,22 @@ my $RxMTA = {
     'subject'  => qr/\AReturned Mail: /,
 };
 
-sub version     { '4.1.0' }
 sub description { 'Unknown MTA #1' }
 sub smtpagent   { 'X1' }
 
 sub scan {
-    # @Description  Detect an error from Unknown MTA #1
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Hash) Bounce data list and message/rfc822 part
+    # Detect an error from Unknown MTA #1
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
+    # @since v4.1.3
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
@@ -34,6 +41,9 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $readcursor = 0;     # (Integer) Points the current cursor position
+    my $indicators = __PACKAGE__->INDICATORS;
+
     my $datestring = '';
     my $longfields = __PACKAGE__->LONGFIELDS;
     my @stripedtxt = split( "\n", $$mbody );
@@ -46,7 +56,17 @@ sub scan {
 
     for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
-        if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
+        unless( $readcursor ) {
+            # Beginning of the bounce message or delivery status part
+            $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxMTA->{'begin'};
+        }
+
+        unless( $readcursor & $indicators->{'message-rfc822'} ) {
+            # Beginning of the original message part
+            $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxMTA->{'rfc822'};
+        }
+
+        if( $readcursor & $indicators->{'message-rfc822'} ) {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
@@ -73,7 +93,7 @@ sub scan {
 
         } else {
             # Before "message/rfc822"
-            next unless ( $e =~ $RxMTA->{'begin'} ) .. ( $e =~ $RxMTA->{'rfc822'} );
+            next unless $readcursor & $indicators->{'deliverystatus'};
             next unless length $e;
 
             # The original message was received at Thu, 29 Apr 2010 23:34:45 +0900 (JST) 
@@ -153,12 +173,6 @@ in the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
-=head2 C<B<version()>>
-
-C<version()> returns the version number of this module.
-
-    print Sisimai::MTA::X1->version;
-
 =head2 C<B<description()>>
 
 C<description()> returns description string of this module.
