@@ -44,15 +44,21 @@ my $RxEMS = qr{(?>                                          # Subject:
     )
 }xi;
 
-sub version     { '4.0.26' };
 sub description { 'Fallback Module for MTAs' };
 sub smtpagent   { 'RFC3464' };
 
 sub scan {
-    # @Description  Detect an error for RFC3464
-    # @Param <ref>  (Ref->Hash) Message header
-    # @Param <ref>  (Ref->String) Message body
-    # @Return       (Ref->Array) Bounce data list
+    # Detect an error for RFC3464
+    # @param         [Hash] mhead       Message header of a bounce email
+    # @options mhead [String] from      From header
+    # @options mhead [String] date      Date header
+    # @options mhead [String] subject   Subject header
+    # @options mhead [Array]  received  Received headers
+    # @options mhead [String] others    Other required headers
+    # @param         [String] mbody     Message body of a bounce email
+    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
+    #                                   or Undef if it failed to parse or the
+    #                                   arguments are missing
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
@@ -72,6 +78,9 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $readcursor = 0;     # (Integer) Points the current cursor position
+    my $indicators = Sisimai::MTA->INDICATORS;
+
     my $longfields = Sisimai::MTA->LONGFIELDS;
     my $scannedset = Sisimai::MDA->scan( $mhead, $mbody );
     my @stripedtxt = split( "\n", $$mbody );
@@ -89,7 +98,17 @@ sub scan {
 
     for my $e ( @stripedtxt ) {
         # Read each line between $RxRFC->{'begin'} and $RxRFC->{'rfc822'}.
-        if( ( $e =~ $RxRFC->{'rfc822'} ) .. ( $e =~ $RxRFC->{'endof'} ) ) {
+        unless( $readcursor ) {
+            # Beginning of the bounce message or delivery status part
+            $readcursor |= $indicators->{'deliverystatus'} if $e =~ $RxRFC->{'begin'};
+        }
+
+        unless( $readcursor & $indicators->{'message-rfc822'} ) {
+            # Beginning of the original message part
+            $readcursor |= $indicators->{'message-rfc822'} if $e =~ $RxRFC->{'rfc822'};
+        }
+
+        if( $readcursor & $indicators->{'message-rfc822'} ) {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
                 # Get required headers only
@@ -117,7 +136,7 @@ sub scan {
 
         } else {
             # Before "message/rfc822"
-            next unless ( $e =~ $RxRFC->{'begin'} ) .. ( $e =~ $RxRFC->{'rfc822'} );
+            next unless $readcursor & $indicators->{'deliverystatus'};
             next unless length $e;
 
             $v = $dscontents->[ -1 ];
@@ -493,12 +512,6 @@ when other Sisimai::MTA::* modules did not detected a bounce reason.
 
 =head1 CLASS METHODS
 
-=head2 C<B<version()>>
-
-C<version()> returns the version number of this module.
-
-    print Sisimai::RFC3464->version;
-
 =head2 C<B<description()>>
 
 C<description()> returns description string of this module.
